import argparse

short_description = 'sgi - Super Git Ignore, tool for faster creation/modification of .gitignore files.'
parser = argparse.ArgumentParser(description=short_description)


def f(*args, **kwargs):
    """
    Purpose of this function is for tests to be executed
    """
    return 1


def main():
    args = parser.parse_args()
    f(args)  # So that flake can ignore args being not used.
    print('It works!')
    # DO_STUFF
